==> dyedvoid-1.0.3%2Bmc1.21.1-sources.jar: archives/tater/dyedvoid/DyedVoidBlocks.java <==
package archives.tater.dyedvoid;

import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2591;
import net.minecraft.class_4970;
import net.minecraft.class_4970.class_2251;
import net.minecraft.class_6862;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import org.jetbrains.annotations.Nullable;

public class DyedVoidBlocks {

    private static class_2248 register(String name, class_2248 block) {
        return class_2378.method_10230(class_7923.field_41175, DyedVoid.id(name), block);
    }

    private static class_2248 registerVoidBlock(@Nullable String colorName, boolean luminant) {
        var settings = class_4970.class_2251.method_9637()
                .method_9632(0)
                .method_36557(3)
                .method_9626(DyedVoidSounds.VOID_BLOCK_SOUND_GROUP)
                .method_45477();

        if (luminant)
            settings
                    .method_26249((state, world, pos) -> true)
                    .method_9631(state -> 15);

        return register(colorName == null ? "void" : colorName + "_void", new VoidBlock(settings));
    }

    private static class_2248 registerVoidBlock(String colorName) {
        return registerVoidBlock(colorName, true);
    }

    public static final class_2248 WHITE_VOID = registerVoidBlock("white");
    public static final class_2248 LIGHT_GRAY_VOID = registerVoidBlock("light_gray");
    public static final class_2248 GRAY_VOID = registerVoidBlock("gray");
    public static final class_2248 BLACK_VOID = registerVoidBlock(null, false);
    public static final class_2248 BROWN_VOID = registerVoidBlock("brown");
    public static final class_2248 RED_VOID = registerVoidBlock("red");
    public static final class_2248 ORANGE_VOID = registerVoidBlock("orange");
    public static final class_2248 YELLOW_VOID = registerVoidBlock("yellow");
    public static final class_2248 LIME_VOID = registerVoidBlock("lime");
    public static final class_2248 GREEN_VOID = registerVoidBlock("green");
    public static final class_2248 CYAN_VOID = registerVoidBlock("cyan");
    public static final class_2248 LIGHT_BLUE_VOID = registerVoidBlock("light_blue");
    public static final class_2248 BLUE_VOID = registerVoidBlock("blue");
    public static final class_2248 PURPLE_VOID = registerVoidBlock("purple");
    public static final class_2248 MAGENTA_VOID = registerVoidBlock("magenta");
    public static final class_2248 PINK_VOID = registerVoidBlock("pink");

    public static final class_2248 END_VOID = register("end_void", new EndVoidBlock(class_4970.class_2251.method_9637()
            .method_9632(0)
            .method_36557(3)
            .method_9626(DyedVoidSounds.VOID_BLOCK_SOUND_GROUP)
            .method_45477()
    ));
    public static final class_2591<EndVoidBlock.EndVoidBlockEntity> END_VOID_BLOCK_ENTITY = class_2378.method_10230(
            class_7923.field_41181,
            DyedVoid.id("end_void"),
            class_2591.class_2592.method_20528(EndVoidBlock.EndVoidBlockEntity::new, END_VOID).build()
    );

    public static final class_2248[] VOID_BLOCKS = {
            BLACK_VOID,
            WHITE_VOID,
            LIGHT_GRAY_VOID,
            GRAY_VOID,
            BROWN_VOID,
            RED_VOID,
            ORANGE_VOID,
            YELLOW_VOID,
            LIME_VOID,
            GREEN_VOID,
            CYAN_VOID,
            LIGHT_BLUE_VOID,
            BLUE_VOID,
            PURPLE_VOID,
            MAGENTA_VOID,
            PINK_VOID,
            END_VOID
    };

    public static final class_6862<class_2248> VOID_BLOCKS_TAG = class_6862.method_40092(class_7924.field_41254, DyedVoid.id("void_blocks"));

    public static void initialize() {}
}

==> dyedvoid-1.0.4%2Bmc1.21.10-sources.jar: archives/tater/dyedvoid/DyedVoidBlocks.java <==
package archives.tater.dyedvoid;

import net.fabricmc.fabric.api.object.builder.v1.block.entity.FabricBlockEntityTypeBuilder;
import net.minecraft.class_2248;
import net.minecraft.class_2378;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_4970;
import net.minecraft.class_5321;
import net.minecraft.class_6862;
import net.minecraft.class_7923;
import net.minecraft.class_7924;
import org.jetbrains.annotations.Nullable;

import java.util.function.Function;

public class DyedVoidBlocks {

    private static class_2248 register(class_2960 identifier, Function<class_4970.class_2251, class_2248> block, class_4970.class_2251 settings) {
        var key = class_5321.method_29179(class_7924.field_41254, identifier);
        return class_2378.method_39197(class_7923.field_41175, key, block.apply(settings.method_63500(key)));
    }

    private static class_2248 register(String path, Function<class_4970.class_2251, class_2248> block, class_4970.class_2251 settings) {
        return register(DyedVoid.id(path), block, settings);
    }

    private static class_2248 register(String path, class_4970.class_2251 settings) {
        return register(path, class_2248::new, settings);
    }

    private static class_2248 registerVoidBlock(@Nullable String colorName, boolean luminant) {
        var settings = class_4970.class_2251.method_9637()
                .method_9632(0)
                .method_36557(3)
                .method_9626(DyedVoidSounds.VOID_BLOCK_SOUND_GROUP)
                .method_9631(luminant ? state -> 15 : state -> 0)
                .method_45477();

        return register(colorName == null ? "void" : colorName + "_void", VoidBlock::new, settings);
    }

    private static class_2248 registerVoidBlock(String colorName) {
        return registerVoidBlock(colorName, true);
    }

    public static final class_2248 WHITE_VOID = registerVoidBlock("white");
    public static final class_2248 LIGHT_GRAY_VOID = registerVoidBlock("light_gray");
    public static final class_2248 GRAY_VOID = registerVoidBlock("gray");
    public static final class_2248 BLACK_VOID = registerVoidBlock(null, false);
    public static final class_2248 BROWN_VOID = registerVoidBlock("brown");
    public static final class_2248 RED_VOID = registerVoidBlock("red");
    public static final class_2248 ORANGE_VOID = registerVoidBlock("orange");
    public static final class_2248 YELLOW_VOID = registerVoidBlock("yellow");
    public static final class_2248 LIME_VOID = registerVoidBlock("lime");
    public static final class_2248 GREEN_VOID = registerVoidBlock("green");
    public static final class_2248 CYAN_VOID = registerVoidBlock("cyan");
    public static final class_2248 LIGHT_BLUE_VOID = registerVoidBlock("light_blue");
    public static final class_2248 BLUE_VOID = registerVoidBlock("blue");
    public static final class_2248 PURPLE_VOID = registerVoidBlock("purple");
    public static final class_2248 MAGENTA_VOID = registerVoidBlock("magenta");
    public static final class_2248 PINK_VOID = registerVoidBlock("pink");

    public static final class_2248 END_VOID = register("end_void", EndVoidBlock::new, class_4970.class_2251.method_9637()
            .method_9632(0)
            .method_36557(3)
            .method_9626(DyedVoidSounds.VOID_BLOCK_SOUND_GROUP)
            .method_45477()
    );
    public static final class_2591<EndVoidBlock.EndVoidBlockEntity> END_VOID_BLOCK_ENTITY = class_2378.method_10230(
            class_7923.field_41181,
            DyedVoid.id("end_void"),
            FabricBlockEntityTypeBuilder.create(EndVoidBlock.EndVoidBlockEntity::new, END_VOID).build()
    );

    public static final class_2248[] VOID_BLOCKS = {
            BLACK_VOID,
            WHITE_VOID,
            LIGHT_GRAY_VOID,
            GRAY_VOID,
            BROWN_VOID,
            RED_VOID,
            ORANGE_VOID,
            YELLOW_VOID,
            LIME_VOID,
            GREEN_VOID,
            CYAN_VOID,
            LIGHT_BLUE_VOID,
            BLUE_VOID,
            PURPLE_VOID,
            MAGENTA_VOID,
            PINK_VOID,
            END_VOID
    };

    public static final class_6862<class_2248> VOID_BLOCKS_TAG = class_6862.method_40092(class_7924.field_41254, DyedVoid.id("void_blocks"));

    public static void initialize() {}
}
